"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path = require("path");
const chalk_1 = require("chalk");
const format_1 = require("@ionic/cli-framework/utils/format");
const string_1 = require("@ionic/cli-framework/utils/string");
const command_1 = require("@ionic/cli-utils/lib/command");
class InfoCommand extends command_1.Command {
    getMetadata() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return {
                name: 'info',
                type: 'global',
                description: 'Print system/environment info',
            };
        });
    }
    run(inputs, options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const task = this.env.tasks.next('Gathering environment info');
            const initialValue = [];
            const results = yield this.env.getInfo();
            const flattenedResults = results.reduce((acc, currentValue) => acc.concat(currentValue), initialValue);
            const cliDetails = flattenedResults.filter(item => item.type === 'cli-packages');
            const globalNpmDetails = flattenedResults.filter(item => item.type === 'global-packages');
            const localNpmDetails = flattenedResults.filter(item => item.type === 'local-packages');
            const systemDetails = flattenedResults.filter(item => item.type === 'system');
            const environmentDetails = flattenedResults.filter(item => item.type === 'environment');
            const miscDetails = flattenedResults.filter(item => item.type === 'misc');
            const ionicPkg = cliDetails.find(item => item.key === 'ionic');
            const pkgPath = ionicPkg && ionicPkg.path ? path.dirname(ionicPkg.path) : undefined;
            const splitInfo = (ary) => ary
                .sort((a, b) => string_1.strcmp(a.key.toLowerCase(), b.key.toLowerCase()))
                .map((item) => [`   ${item.key}${item.flair ? ' ' + chalk_1.default.dim('(' + item.flair + ')') : ''}`, chalk_1.default.dim(item.value) + (item.path && pkgPath && !item.path.startsWith(pkgPath) ? ` ${chalk_1.default.dim('(' + item.path + ')')}` : '')]);
            const format = (details) => format_1.columnar(details, { vsep: ':' });
            task.end();
            if (!this.env.project.directory) {
                this.env.log.warn('You are not in an Ionic project directory. Project context may be missing.');
            }
            if (cliDetails.length > 0) {
                this.env.log.rawmsg(`${chalk_1.default.bold('cli packages:')}${pkgPath ? ' ' + chalk_1.default.dim('(' + pkgPath + ')') : ''}\n\n`);
                this.env.log.rawmsg(`${format(splitInfo(cliDetails))}\n\n`);
            }
            if (globalNpmDetails.length > 0) {
                this.env.log.rawmsg(`${chalk_1.default.bold('global packages:')}\n\n`);
                this.env.log.rawmsg(`${format(splitInfo(globalNpmDetails))}\n\n`);
            }
            if (localNpmDetails.length > 0) {
                this.env.log.rawmsg(`${chalk_1.default.bold('local packages:')}\n\n`);
                this.env.log.rawmsg(`${format(splitInfo(localNpmDetails))}\n\n`);
            }
            if (systemDetails.length > 0) {
                this.env.log.rawmsg(`${chalk_1.default.bold('System:')}\n\n`);
                this.env.log.rawmsg(`${format(splitInfo(systemDetails))}\n\n`);
            }
            if (environmentDetails.length > 0) {
                this.env.log.rawmsg(`${chalk_1.default.bold('Environment Variables:')}\n\n`);
                this.env.log.rawmsg(`${format(splitInfo(environmentDetails))}\n\n`);
            }
            if (miscDetails.length > 0) {
                this.env.log.rawmsg(`${chalk_1.default.bold('Misc:')}\n\n`);
                this.env.log.rawmsg(`${format(splitInfo(miscDetails))}\n\n`);
            }
        });
    }
}
exports.InfoCommand = InfoCommand;
